{% extends "base.html" %}
{% load i18n %}
{% block title %}Select your Home Organization{% endblock %}
{% block header %}Select your Home Organization{% endblock %}
{% block content %}
<p>In order to proceed, you have to select your Home Organization from the list below. You may save your selection, in order to avoid this question during future uses of this service.</p>

<div id="idpform">
<form id="idp_selection" method="post">
    {% csrf_token %}
	<select name="user_idp">
	{% include "idp_dropdown.html" %}
	</select>
	<input type="submit" value="{% trans "Confirm" %}" /><br />
	<script type="text/javascript">
	function toggleRadios(){
		var state;
		state = ! document.forms[0].save.checked;
		document.getElementById('permsave').disabled = state;
		document.getElementById('sesssave').disabled = state;
	}
	</script>
	<div id="userprefs">
	<input type="checkbox" name="save" value="1" onclick="toggleRadios();"/>Save my preference:</input>
	<input type="radio" id="sesssave" name="savetype" value="session" disabled="true" checked="true" />For this browser session</input>
	<input type="radio" id="permsave" name="savetype" value="perm" disabled="true" />Permanently</input><br />
	</div>
</form>
</div>

{% endblock %}
