{% load i18n %}
{% get_current_language as LANGUAGE_CODE %}
<!DOCTYPE html>
<html>
<head>
<title>{% block title %}{% endblock %}</title>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" lang="{{ LANGUAGE_CODE }}">
<meta name="robots" content="ALL">
<meta name="revisit-after" content="30 days">
<link href="/static/style.css" rel="stylesheet" type="text/css">
</head>

<body>

<!--div id="language">
	<div id="language-container">
		<div id="language-div">
			<div id="langtop"><div></div></div>
			<-a href="/setlanguage/el">Ελληνικά</a>&nbsp;&nbsp;•&nbsp;&nbsp;<a href="/setlanguage/en">English</a>
		</div>
	</div>
</div-->

<div id="content">

	<h1>{% block header %}{% endblock %}</h1>
	<div id="rbroundbox">
		<div id="rbtop"><div></div></div>
		<div id="rbcontent">
{% block content %}
{% endblock %}
		</div>
		<div id="rbbot"><div></div></div>
	</div>
	<div id="pagebot"><div></div></div>
</div>
</body>
</html>
