{% extends "base.html" %}
{% load i18n %}
{% block title %}{% trans "Select your home institution" %}{% endblock %}
{% block header %}{% trans "Select your home institution" %}{% endblock %}
{% block content %}
<p>
Your selected Home Organization is:
</p>
<div align="center">
<h4>{{ currentidp }}</h4>
<form method="post">
    {% csrf_token %}
	<input type="hidden" name="clear" value="true" />
	<input type="submit" value="{% trans "Clear" %}" />
</form>
</div>
<p>
A default setting for your Home Organization has the effect that you don't need to select your Home Organization anymore when accessing this webpage with this web browser.
</p>
{% endblock %}
