	{% for category, insts in  idplist %}
		<optgroup label="{{ category.name }}">
		{% for inst in insts %}
			{% ifequal inst.id selected.id %}
			<option value="{{ inst.id }}" selected="true">{{ inst.name }}</option>
			{% else %}
			<option value="{{ inst.id }}">{{ inst.name }}</option>
			{% endifequal %}
		{% endfor %}
		</optgroup>
	{% endfor %}
