{% extends "base.html" %}
{% load i18n %}
{% block title %}{% trans "Page not found" %}{% endblock %}
{% block header %}{% trans "Page not found" %}{% endblock %}
{% block content %}
{% trans "The page you requested could not be found!" %}
{% endblock %}
