{% extends "base.html" %}
{% load i18n %}
{% block title %}{% trans "Permanently set your Home Organization" %}{% endblock %}
{% block header %}{% trans "Permanently set your Home Organization" %}{% endblock %}
{% block content %}
<p>On this page you can set a default Home Organization for this web browser. Setting a default Home Organization will henceforth redirect you directly to your Home Organization when you access this webpage. Don't use this feature if you use several accounts.</p>
<div id="idpform">
<form id="idp_selection" method="post">
    {% csrf_token %}
	<select name="user_idp">
	{% include "idp_dropdown.html" %}
	</select>
	<input type="submit" value="{% trans "Confirm" %}" /><br />
	<input type="hidden" name="save" value="true" />
	<input type="hidden" name="savetype" value="perm" />
</form>
</div>
{% endblock %}
