{% extends "base.html" %}
{% load i18n %}
{% block title %}{% trans "Server error" %}{% endblock %}
{% block header %}{% trans "Server error" %}{% endblock %}
{% block content %}
{% trans "The page you requested cannot be displayed because the server experienced a technical problem. We apologize for the inconvenience." %}
{% endblock %}
